# MCP Registry Documentation

The MCP registry provides MCP clients with a list of MCP servers, like an app store for MCP servers.

## I want to...

- **📤 Publish my MCP server** → [Publishing Guide](modelcontextprotocol-io/quickstart.mdx)
- **📥 Consume registry data** → [API Usage Guide](modelcontextprotocol-io/registry-aggregators.mdx)
- **🔌 Understand the registry's purpose** → [Ecosystem vision](design/ecosystem-vision.md)
- **📋 Look up specific information** → [server.json spec](reference/server-json/generic-server-json.md) | [API spec](reference/api/generic-registry-api.md) | [CLI reference](reference/cli/commands.md)
- **🤝 Add reference to my community project** → [Community Projects](community-projects.md)

## Documentation Index

- 📄 [Public-facing docs](./modelcontextprotocol-io/) - Published on modelcontextprotocol.io
- 🏗️ [Design documentation](./design/) - Architecture, vision, and roadmap
- 📖 [Reference](./reference/) - Technical specifications
- 🔧 [Contributing guides](./contributing/) - How to contribute
- 🔒 [Administration](./administration/) - Admin operations
